SwirlDesignTokensLight class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- actionCriticalDefault → const Color
- actionCriticalDisabled → const Color
- actionCriticalHovered → const Color
- actionCriticalPressed → const Color
- actionNeutralDefault → const Color
- actionNeutralDisabled → const Color
- actionNeutralHovered → const Color
- actionNeutralPressed → const Color
- actionPrimaryDefault → const Color
- actionPrimaryDisabled → const Color
- actionPrimaryHovered → const Color
- actionPrimaryPressed → const Color
- backgroundDefault → const Color
- backgroundHovered → const Color
- backgroundPressed → const Color
- blurL → const String
- blurM → const String
- blurS → const String
- borderCritical → const Color
- borderDefault → const Color
- borderHighlight → const Color
- borderInfo → const Color
- borderOnHighlight → const Color
- borderOnTranslucent → const Color
- borderRadiusBase → const double
- borderRadiusFullRound → const double
- borderRadiusL → const double
- borderRadiusNull → const double
- borderRadiusS → const double
- borderRadiusSm → const double
- borderRadiusXl → const double
- borderRadiusXs → const double
- borderStrong → const Color
- borderSuccess → const Color
- borderTranslucentOutline → const Color
- borderWarning → const Color
- borderWidth0 → const double
- borderWidthDefault → const double
- coreCustomerColorDark1Default → const Color
- coreCustomerColorDark1Hovered → const Color
- coreCustomerColorDark1Pressed → const Color
- coreCustomerColorDark2Default → const Color
- coreCustomerColorDark2Hovered → const Color
- coreCustomerColorDark2Pressed → const Color
- coreCustomerColorDark3Default → const Color
- coreCustomerColorDark3Hovered → const Color
- coreCustomerColorDark3Pressed → const Color
- coreCustomerColorLight1Default → const Color
- coreCustomerColorLight1Hovered → const Color
- coreCustomerColorLight1Pressed → const Color
- coreCustomerColorLight2Default → const Color
- coreCustomerColorLight2Hovered → const Color
- coreCustomerColorLight2Pressed → const Color
- coreCustomerColorLight3Default → const Color
- coreCustomerColorLight3Hovered → const Color
- coreCustomerColorLight3Pressed → const Color
- coreDecorativeDarkBananaSurface → const Color
- coreDecorativeDarkBananaSurfaceSubdued → const Color
- coreDecorativeDarkBananaText → const Color
- coreDecorativeDarkBlueberrySurface → const Color
- coreDecorativeDarkBlueberrySurfaceSubdued → const Color
- coreDecorativeDarkBlueberryText → const Color
- coreDecorativeDarkChilliSurface → const Color
- coreDecorativeDarkChilliSurfaceSubdued → const Color
- coreDecorativeDarkChilliText → const Color
- coreDecorativeDarkGrapeSurface → const Color
- coreDecorativeDarkGrapeSurfaceSubdued → const Color
- coreDecorativeDarkGrapeText → const Color
- coreDecorativeDarkKiwiSurface → const Color
- coreDecorativeDarkKiwiSurfaceSubdued → const Color
- coreDecorativeDarkKiwiText → const Color
- coreDecorativeDarkPumpkinSurface → const Color
- coreDecorativeDarkPumpkinSurfaceSubdued → const Color
- coreDecorativeDarkPumpkinText → const Color
- coreDecorativeDarkRadishSurface → const Color
- coreDecorativeDarkRadishSurfaceSubdued → const Color
- coreDecorativeDarkRadishText → const Color
- coreDecorativeLightBananaSurface → const Color
- coreDecorativeLightBananaSurfaceSubdued → const Color
- coreDecorativeLightBananaText → const Color
- coreDecorativeLightBlueberrySurface → const Color
- coreDecorativeLightBlueberrySurfaceSubdued → const Color
- coreDecorativeLightBlueberryText → const Color
- coreDecorativeLightChilliSurface → const Color
- coreDecorativeLightChilliSurfaceSubdued → const Color
- coreDecorativeLightChilliText → const Color
- coreDecorativeLightGrapeSurface → const Color
- coreDecorativeLightGrapeSurfaceSubdued → const Color
- coreDecorativeLightGrapeText → const Color
- coreDecorativeLightKiwiSurface → const Color
- coreDecorativeLightKiwiSurfaceSubdued → const Color
- coreDecorativeLightKiwiText → const Color
- coreDecorativeLightPumpkinSurface → const Color
- coreDecorativeLightPumpkinSurfaceSubdued → const Color
- coreDecorativeLightPumpkinText → const Color
- coreDecorativeLightRadishSurface → const Color
- coreDecorativeLightRadishSurfaceSubdued → const Color
- coreDecorativeLightRadishText → const Color
- coreGray01 → const Color
- coreGray02 → const Color
- coreGray03 → const Color
- coreGray04 → const Color
- coreGray05 → const Color
- coreGray06 → const Color
- coreGray07 → const Color
- coreGray08 → const Color
- coreGray09 → const Color
- coreGray10 → const Color
- coreGray11 → const Color
- coreGray12 → const Color
- coreGrayBlack → const Color
- coreGrayWhite → const Color
- coreOnCustomerColorDark1 → const Color
- coreOnCustomerColorDark2 → const Color
- coreOnCustomerColorDark2Subdued → const Color
- coreOnCustomerColorLight1 → const Color
- coreOnCustomerColorLight2 → const Color
- coreOnCustomerColorLight2Subdued → const Color
- coreStatusDarkCriticalDefault → const Color
- coreStatusDarkCriticalHovered → const Color
- coreStatusDarkCriticalPressed → const Color
- coreStatusDarkCriticalSubdued → const Color
- coreStatusDarkInfoDefault → const Color
- coreStatusDarkInfoSubdued → const Color
- coreStatusDarkSuccessDefault → const Color
- coreStatusDarkSuccessSubdued → const Color
- coreStatusDarkWarningDefault → const Color
- coreStatusDarkWarningSubdued → const Color
- coreStatusLightCriticalDefault → const Color
- coreStatusLightCriticalHovered → const Color
- coreStatusLightCriticalPressed → const Color
- coreStatusLightCriticalSubdued → const Color
- coreStatusLightInfoDefault → const Color
- coreStatusLightInfoSubdued → const Color
- coreStatusLightSuccessDefault → const Color
- coreStatusLightSuccessSubdued → const Color
- coreStatusLightWarningDefault → const Color
- coreStatusLightWarningStrong → const Color
- coreStatusLightWarningSubdued → const Color
- coreTranslucentBlack3 → const Color
- coreTranslucentBlack6 → const Color
- coreTranslucentBlack9 → const Color
- coreTranslucentBlack12 → const Color
- coreTranslucentBlack20 → const Color
- coreTranslucentBlack60 → const Color
- coreTranslucentBlack80 → const Color
- coreTranslucentWhite3 → const Color
- coreTranslucentWhite6 → const Color
- coreTranslucentWhite9 → const Color
- coreTranslucentWhite12 → const Color
- coreTranslucentWhite20 → const Color
- coreTranslucentWhite60 → const Color
- coreTranslucentWhite80 → const Color
- decorationNone → const String
- decorationUnderline → const String
- decorativeBananaSurface → const Color
- decorativeBananaSurfaceSubdued → const Color
- decorativeBananaText → const Color
- decorativeBlueberrySurface → const Color
- decorativeBlueberrySurfaceSubdued → const Color
- decorativeBlueberryText → const Color
- decorativeChilliSurface → const Color
- decorativeChilliSurfaceSubdued → const Color
- decorativeChilliText → const Color
- decorativeGrapeSurface → const Color
- decorativeGrapeSurfaceSubdued → const Color
- decorativeGrapeText → const Color
- decorativeKiwiSurface → const Color
- decorativeKiwiSurfaceSubdued → const Color
- decorativeKiwiText → const Color
- decorativePumpkinSurface → const Color
- decorativePumpkinSurfaceSubdued → const Color
- decorativePumpkinText → const Color
- decorativeRadishSurface → const Color
- decorativeRadishSurfaceSubdued → const Color
- decorativeRadishText → const Color
- focusDefault → const Color
- fontFamilyCode → const String
- fontFamilyText → const String
- fontFamilyTextArabic → const String
- fontFamilyTextChineseSimplified → const String
- fontFamilyTextChineseTraditional → const String
- fontFamilyTextJapanese → const String
- fontFamilyTextKorean → const String
- fontSize2xl → const double
- fontSizeBase → const double
- fontSizeLg → const double
- fontSizeSm → const double
- fontSizeXl → const double
- fontSizeXs → const double
- fontWeightBold → const FontWeight
- fontWeightMedium → const FontWeight
- fontWeightNormal → const FontWeight
- fontWeightSemibold → const FontWeight
- iconCritical → const Color
- iconDark → const Color
- iconDefault → const Color
- iconDisabled → const Color
- iconHighlight → const Color
- iconInfo → const Color
- iconOnActionPrimary → const Color
- iconOnImage → const Color
- iconOnStatus → const Color
- iconOnSurfaceHighlight → const Color
- iconOnSurfaceHighlightSubdued → const Color
- iconStrong → const Color
- iconSuccess → const Color
- iconWarning → const Color
- interactiveCriticalDefault → const Color
- interactiveCriticalDisabled → const Color
- interactiveCriticalHovered → const Color
- interactiveCriticalPressed → const Color
- interactiveNeutralDefault → const Color
- interactiveNeutralDisabled → const Color
- interactiveNeutralHovered → const Color
- interactiveNeutralPressed → const Color
- interactivePrimaryDefault → const Color
- interactivePrimaryDisabled → const Color
- interactivePrimaryHovered → const Color
- interactivePrimaryPressed → const Color
- letterSpacingNormal → const double
- lineHeight2xl → const double
- lineHeightBase → const double
- lineHeightLg → const double
- lineHeightSm → const double
- lineHeightXl → const double
- lineHeightXs → const double
- onSurfaceHighlightDefault → const Color
-
shadowLevel1
→ const List<
BoxShadow> -
shadowLevel2
→ const List<
BoxShadow> -
shadowLevel3
→ const List<
BoxShadow> - space0 → const double
- space2 → const double
- space4 → const double
- space8 → const double
- space12 → const double
- space16 → const double
- space20 → const double
- space24 → const double
- space32 → const double
- space40 → const double
- space48 → const double
- space64 → const double
- stateHovered → const Color
- statePressed → const Color
- surfaceCriticalDefault → const Color
- surfaceCriticalSubdued → const Color
- surfaceDefault → const Color
- surfaceHighlightDefault → const Color
- surfaceHighlightHovered → const Color
- surfaceHighlightPressed → const Color
- surfaceHovered → const Color
- surfaceInfoDefault → const Color
- surfaceInfoSubdued → const Color
- surfaceNeutralDefault → const Color
- surfaceNeutralSubdued → const Color
- surfaceOnImageDefault → const Color
- surfaceOverlayDefault → const Color
- surfaceOverlayHovered → const Color
- surfaceOverlayPressed → const Color
- surfacePressed → const Color
- surfaceRaised50Default → const Color
- surfaceRaised50Hovered → const Color
- surfaceRaised50Pressed → const Color
- surfaceRaisedDefault → const Color
- surfaceRaisedHovered → const Color
- surfaceRaisedPressed → const Color
- surfaceSuccessDefault → const Color
- surfaceSuccessSubdued → const Color
- surfaceSunkenDefault → const Color
- surfaceSunkenHovered → const Color
- surfaceSunkenPressed → const Color
- surfaceWarningDefault → const Color
- surfaceWarningSubdued → const Color
- textCritical → const Color
- textDark → const Color
- textDefault → const Color
- textDisabled → const Color
- textHighlight → const Color
- textInfo → const Color
- textOnActionPrimary → const Color
- textOnImage → const Color
- textOnStatus → const Color
- textOnSurfaceHighlight → const Color
- textOnSurfaceHighlightSubdued → const Color
- textSubdued → const Color
- textSuccess → const Color
- textWarning → const Color
- translucentLowDefault → const Color
- translucentLowHovered → const Color
- translucentLowPressed → const Color
- translucentMediumDefault → const Color
- translucentMediumHovered → const Color
- translucentMediumPressed → const Color
- z0 → const String
- z10 → const String
- z20 → const String
- z30 → const String
- z40 → const String
- z50 → const String
- zAuto → const String